# nornir-salt
Collection of Nornir plugins used with [SALTSTACK Nornir modules](https://github.com/dmulyalin/salt-nornir).

All plugins and functions can be used with Nornir directly unless stated otherwise.

Reference [documentation](https://nornir-salt.readthedocs.io/en/latest/) for additional information.

# Contributing

Issues, bug reports and feature requests are welcomed.

[buy](https://paypal.me/dmulyalin) Author a coffee
